@@ -7,6 +7,9 @@ from retrying import retry
 
 
 def send_request(method, url, headers=None, params=None, data=None, proxies=None, timeout=10, max_attempt_number=3):
+    if isinstance(proxies, str):
+        proxies = {"https": proxies, "http": proxies}
+
     @retry(stop_max_attempt_number=max_attempt_number)
     def _send_request():
         response = requests.request(method, url, headers=headers, params=params, data=data, proxies=proxies,
