@@ -22,7 +22,7 @@ class GoogleTranslate(BaseTranslate):
     def trans_text_other2en(self):
         url = f'http://translate.google.cn/translate_a/single?client=gtx&dt=t&dj=1&ie=UTF-8&sl=auto&tl=en&q={self.content}'
         r = send_request('get', url, proxies=self.proxies)
-        self.logger.info(r.text)
+        # self.logger.info(r.text)
         rs = []
         for result in r.json()['sentences']:
             rs.append(result['trans'])
@@ -31,8 +31,8 @@ class GoogleTranslate(BaseTranslate):
 
 if __name__ == '__main__':
     for source_text in ['china', '저는 중국사람입니다']:
-        rs = GoogleTranslate(content=source_text).trans_text_other2cn()
-        print(rs)
+        _rs = GoogleTranslate(content=source_text).trans_text_other2cn()
+        print(_rs)
     for source_text in ['中国', '저는 중국사람입니다']:
         res = GoogleTranslate(content=source_text).trans_text_other2en()
         print(res)
